Matchbox is a tool to make record matching iterative, collaborative and measurable.

It allows you to connect data using your organisation's best possible intelligence, and makes querying connected data quicker than a left join.

The Matchbox package is [published on PyPi](https://pypi.org/project/matchbox-db/) and can be installed with:

```
pip install matchbox-db
```

You can use Matchbox to:

* Retrieve data that others have linked or deduplicated using Matchbox
* Build matching pipelines to link or deduplicate data